@@ -19,7 +19,7 @@ Usage::
     list_keys_paginator: ListKeysPaginator = client.get_paginator("list_keys")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_kms.type_defs import (
     ListAliasesResponseTypeDef,
@@ -40,51 +40,51 @@ __all__ = (
 
 class ListAliasesPaginator(Boto3Paginator):
     """
-    [Paginator.ListAliases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/kms.html#KMS.Paginator.ListAliases)
+    [Paginator.ListAliases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/kms.html#KMS.Paginator.ListAliases)
     """
 
     def paginate(
         self, KeyId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListAliasesResponseTypeDef, None, None]:
+    ) -> Iterator[ListAliasesResponseTypeDef]:
         """
-        [ListAliases.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/kms.html#KMS.Paginator.ListAliases.paginate)
+        [ListAliases.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/kms.html#KMS.Paginator.ListAliases.paginate)
         """
 
 
 class ListGrantsPaginator(Boto3Paginator):
     """
-    [Paginator.ListGrants documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/kms.html#KMS.Paginator.ListGrants)
+    [Paginator.ListGrants documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/kms.html#KMS.Paginator.ListGrants)
     """
 
     def paginate(
         self, KeyId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListGrantsResponseTypeDef, None, None]:
+    ) -> Iterator[ListGrantsResponseTypeDef]:
         """
-        [ListGrants.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/kms.html#KMS.Paginator.ListGrants.paginate)
+        [ListGrants.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/kms.html#KMS.Paginator.ListGrants.paginate)
         """
 
 
 class ListKeyPoliciesPaginator(Boto3Paginator):
     """
-    [Paginator.ListKeyPolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/kms.html#KMS.Paginator.ListKeyPolicies)
+    [Paginator.ListKeyPolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/kms.html#KMS.Paginator.ListKeyPolicies)
     """
 
     def paginate(
         self, KeyId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListKeyPoliciesResponseTypeDef, None, None]:
+    ) -> Iterator[ListKeyPoliciesResponseTypeDef]:
         """
-        [ListKeyPolicies.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/kms.html#KMS.Paginator.ListKeyPolicies.paginate)
+        [ListKeyPolicies.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/kms.html#KMS.Paginator.ListKeyPolicies.paginate)
         """
 
 
 class ListKeysPaginator(Boto3Paginator):
     """
-    [Paginator.ListKeys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/kms.html#KMS.Paginator.ListKeys)
+    [Paginator.ListKeys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/kms.html#KMS.Paginator.ListKeys)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListKeysResponseTypeDef, None, None]:
+    ) -> Iterator[ListKeysResponseTypeDef]:
         """
-        [ListKeys.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/kms.html#KMS.Paginator.ListKeys.paginate)
+        [ListKeys.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/kms.html#KMS.Paginator.ListKeys.paginate)
         """
